Producer-consumer example with callbacks
========================================

.. automodule:: examples.producer_consumer_example_callbacks

.. literalinclude:: ../../examples/producer_consumer_example_callbacks.py
    :start-after: # start-file
